========
Examples
========

Here you will find some example notebooks to get more familiar with the API.



darts intro
===========

You will find below an example Jupyter notebook containing an intro to usage of darts.

.. toctree::
   :maxdepth: 1

   examples/darts-intro.ipynb


Fast Fourier Transform
======================

You will find below an example Jupyter notebook containing usage of FFT model

.. toctree::
   :maxdepth: 1

   examples/FFT-examples.ipynb

Recurrent Neural Networks
=========================

You will find below an example Jupyter notebook containing usage of RNN model

.. toctree::
   :maxdepth: 1

   examples/RNN-examples.ipynb

Temporal Convolutional Networks
===============================

You will find below an example Jupyter notebook containing usage of TCN model

.. toctree::
   :maxdepth: 1

   examples/TCN-examples.ipynb

Multivariate Examples
=====================

You will find below an example Jupyter notebook containing usage of multivariate TimeSeries instances

.. toctree::
   :maxdepth: 1

   examples/multivariate-examples.ipynb

M4 Competition Exploration
==========================

You will find below an example Jupyter notebook with a benchmark of different darts models and example usage of FourTheta model

.. toctree::
    :maxdepth: 1

    examples/M4_competition/M4_competition_benchmark.ipynb
